==> AGXUnreal-1.17.0_UE-5.5_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Signals/AngularVelocity3DInput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics/Signals/Input.h>
#include <openplx/Physics3D/Signals/AngularVelocity3DInputTrait.h>
/* Generated code for model AngularVelocity3DInput */
namespace openplx::Physics3D::Signals {
    /**
     * A vec3 as angular velocity input.
     * For models which have an unambiguous 3D angular velocity input parameter.
     * The input is given as a 3D velocity vector in the world coordinate system, expressed in absolute coordinates.
     **/
    class AngularVelocity3DInput : public openplx::Physics::Signals::Input {
        protected:
            std::weak_ptr<openplx::Physics3D::Signals::AngularVelocity3DInputTrait> m_source;

        public:
            AngularVelocity3DInput();
            std::shared_ptr<openplx::Physics3D::Signals::AngularVelocity3DInputTrait> source() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.5_Linux.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Signals/AngularVelocity3DInput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics/Signals/Input.h>
#include <openplx/Physics3D/Signals/AngularVelocity3DInputTrait.h>
#include <openplx/Physics3D/Signals/Vec3Marshalling.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model AngularVelocity3DInput */
namespace openplx::Physics3D::Signals {
    /**
     * A vec3 as angular velocity input.
     * For models which have an unambiguous 3D angular velocity input parameter.
     * The input is given as a 3D velocity vector in the world coordinate system, expressed in absolute coordinates.
     **/
    class OPENPLX_Physics3D_BUNDLE_EXPORT AngularVelocity3DInput : public openplx::Physics::Signals::Input {
        protected:
            std::weak_ptr<openplx::Physics3D::Signals::AngularVelocity3DInputTrait> m_source;

        public:
            AngularVelocity3DInput();
            virtual ~AngularVelocity3DInput();
            std::shared_ptr<openplx::Physics3D::Signals::AngularVelocity3DInputTrait> source() const;
            std::shared_ptr<openplx::Physics3D::Signals::Vec3Marshalling> marshalling() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
